########
opentype
########

.. toctree::
   :maxdepth: 1

   cff
   cmap
   dsig
   fontval
   fvar
   glyf
   gpos
   head
   hhea
   hmtx
   kern
   loca
   name
   os2
   post



.. automodule:: fontbakery.profiles.opentype
   :members:
   :undoc-members:
 
 .. automodule:: fontbakery.profiles
